@@ -99,7 +99,10 @@ def process(smpp_client, queue):
                                 sender_id=sender_id
                                 )
                         else:
-                            if msisdn.startswith("34") or msisdn.startswith("39"):
+                            if (
+                                msisdn.startswith("34")
+                                or msisdn.startswith("39")
+                            ):
                                 pass
                             else:
                                 smpp_client.send_sms(
@@ -118,7 +121,7 @@ def process(smpp_client, queue):
                             )
                         ch.basic_ack(delivery_tag=method.delivery_tag)
                         response['status'] = 500
-                        response['code'] = SERVICE_CODE+'-5000'
+                        response['code'] = SERVICE_CODE + '-5000'
                         response['error'] = 'Erreur interne'
                         response['message'] = {
                             'msisdn': msisdn,
