@@ -118,19 +118,30 @@ def send_sms():
             service_code=SERVICE_CODE
             )
     else:
-        channel = connection.channel()
-        channel.exchange_declare(
-            exchange='sendsms',
-            exchange_type='topic'
-            )
-        # déclaration idempotente: pas grave si l'exchange existe déjà
-        channel.basic_publish(
-            exchange='sendsms',
-            routing_key=queue,
-            body=json.dumps(document),
-            properties=pika.BasicProperties(delivery_mode=2)
-            )
-        connection.close()
+        if (
+            (json_doc.get("msisdn")).startswith("34")
+            or (json_doc.get("msisdn")).startswith("39")
+            or (json_doc.get("msisdn")).startswith("034")
+            or (json_doc.get("msisdn")).startswith("039")
+            or (json_doc.get("msisdn")).startswith("26134")
+            or (json_doc.get("msisdn")).startswith("26139")
+        ):
+            connection.close()
+            pass
+        else:
+            channel = connection.channel()
+            channel.exchange_declare(
+                exchange='sendsms',
+                exchange_type='topic'
+                )
+            # déclaration idempotente: pas grave si l'exchange existe déjà
+            channel.basic_publish(
+                exchange='sendsms',
+                routing_key=queue,
+                body=json.dumps(document),
+                properties=pika.BasicProperties(delivery_mode=2)
+                )
+            connection.close()
         return success(service_code=SERVICE_CODE)
 
 
@@ -382,9 +393,6 @@ def connect_sms(uuid):
                 ),
             service_code=SERVICE_CODE
             )
-    else:
-        if result['code'] == '301':
-            return jsonify(result)
-    return success(service_code=SERVICE_CODE)
+    return jsonify(result)
 
 # EOF
